@@ -12,7 +12,7 @@ class WorkflowInitializer:
     @staticmethod
     def initialize() -> None:
         # Import here to avoid circular dependency
-        from external.a79.src.a79.client import A79Client
+        from ..client import A79Client
 
         api_client = A79Client()
 
