@@ -1,6 +1,6 @@
-from external.a79.src.a79.client import A79Client
-from external.a79.src.models.tools import DEFAULT
-from external.a79.src.models.tools.audio_models import CreateAudioInput, CreateAudioOutput
+from ..client import A79Client
+from ..models.tools import DEFAULT
+from ..models.tools.audio_models import CreateAudioInput, CreateAudioOutput
 
 __all__ = ["CreateAudioInput", "CreateAudioOutput", "create_audio"]
 
